==> befoo-1.2.1-src.zip: extend/define.h <==
/*
 * Copyright (C) 2009-2010 TSUBAKIMOTO Hiroya <zorac@4000do.co.jp>
 *
 * This software comes with ABSOLUTELY NO WARRANTY; for details of
 * the license terms, see the LICENSE.txt file included with the program.
 */
#define _WIN32_WINNT 0x0500
#define _WIN32_IE 0x0500
#define WINVER _WIN32_WINNT

#define IDD_SETTING				100
#define IDC_LIST_MAILBOX			1000
#define IDC_BUTTON_NEW				1001
#define IDC_BUTTON_EDIT				1002
#define IDC_BUTTON_DELETE			1003
#define IDC_BUTTON_ICON				1004
#define IDC_CHECKBOX_ICON			1005
#define IDC_EDIT_ICON				1006
#define IDC_SPIN_ICON				1007
#define IDC_EDIT_ICONTRANS			1008
#define IDC_SPIN_ICONTRANS			1009
#define IDC_EDIT_BALLOON			1010
#define IDC_SPIN_BALLOON			1011
#define IDC_EDIT_SUMMARY			1012
#define IDC_SPIN_SUMMARY			1013
#define IDC_CHECKBOX_SUMMARY			1014
#define IDC_EDIT_SUMMARYTRANS			1015
#define IDC_SPIN_SUMMARYTRANS			1016
#define IDC_EDIT_STARTUP			1017
#define IDC_SPIN_STARTUP			1018

#define IDD_MAILBOX				101
#define IDC_EDIT_NAME				1000
#define IDC_COMBO_SERVER			1001
#define IDC_BUTTON_SERVER			1002
#define IDC_EDIT_PASSWD				1003
#define IDC_EDIT_FETCH				1004
#define IDC_SPIN_FETCH				1005
#define IDC_COMBO_SOUND				1006
#define IDC_BUTTON_SOUND			1007
#define IDC_BUTTON_PLAY				1008
#define IDC_COMBO_MUA				1009
#define IDC_BUTTON_MUA				1010
#define IDC_COMBO_IP_VERSION			1011
#define IDC_COMBO_VERIFY			1012

#define IDD_URI					102
#define IDC_COMBO_SCHEME			1000
#define IDC_EDIT_USER				1001
#define IDC_EDIT_ADDRESS			1002
#define IDC_EDIT_PORT				1003
#define IDC_SPIN_PORT				1004
#define IDC_EDIT_PATH				1005
#define IDC_CHECKBOX_RECENT			1006

#define IDD_ICON				103
#define IDC_LIST_ICON				1000

#define IDS_FILTER_SOUND			40000
#define IDS_FILTER_PROGRAM			40001
#define IDS_MSGBOX_DELETE			40002
#define IDS_MSG_ITEM_REQUIRED			40003
#define IDS_MSG_INVALID_CHAR			40004
#define IDS_MSG_NAME_EXISTS			40005
#define IDS_LIST_IP_VERSION			40006
#define IDS_LIST_VERIFY				40007

==> befoo-1.3-src.zip: extend/define.h <==
/*
 * Copyright (C) 2009-2011 TSUBAKIMOTO Hiroya <zorac@4000do.co.jp>
 *
 * This software comes with ABSOLUTELY NO WARRANTY; for details of
 * the license terms, see the LICENSE.txt file included with the program.
 */
#define _WIN32_WINNT 0x0500
#define _WIN32_IE 0x0500
#define WINVER _WIN32_WINNT

#define IDD_SETTING				100
#define IDC_LIST_MAILBOX			1000
#define IDC_BUTTON_NEW				1001
#define IDC_BUTTON_EDIT				1002
#define IDC_BUTTON_DELETE			1003
#define IDC_BUTTON_ICON				1004
#define IDC_CHECKBOX_ICON			1005
#define IDC_EDIT_ICON				1006
#define IDC_SPIN_ICON				1007
#define IDC_EDIT_ICONTRANS			1008
#define IDC_SPIN_ICONTRANS			1009
#define IDC_EDIT_BALLOON			1010
#define IDC_SPIN_BALLOON			1011
#define IDC_EDIT_SUBJECTS			1012
#define IDC_SPIN_SUBJECTS			1013
#define IDC_EDIT_SUMMARY			1014
#define IDC_SPIN_SUMMARY			1015
#define IDC_CHECKBOX_SUMMARY			1016
#define IDC_EDIT_SUMMARYTRANS			1017
#define IDC_SPIN_SUMMARYTRANS			1018
#define IDC_EDIT_STARTUP			1019
#define IDC_SPIN_STARTUP			1020

#define IDD_MAILBOX				101
#define IDC_EDIT_NAME				1000
#define IDC_COMBO_SERVER			1001
#define IDC_BUTTON_SERVER			1002
#define IDC_EDIT_PASSWD				1003
#define IDC_EDIT_FETCH				1004
#define IDC_SPIN_FETCH				1005
#define IDC_COMBO_SOUND				1006
#define IDC_BUTTON_SOUND			1007
#define IDC_BUTTON_PLAY				1008
#define IDC_COMBO_MUA				1009
#define IDC_BUTTON_MUA				1010
#define IDC_COMBO_IP_VERSION			1011
#define IDC_COMBO_VERIFY			1012

#define IDD_URI					102
#define IDC_COMBO_SCHEME			1000
#define IDC_EDIT_USER				1001
#define IDC_EDIT_ADDRESS			1002
#define IDC_EDIT_PORT				1003
#define IDC_SPIN_PORT				1004
#define IDC_EDIT_PATH				1005
#define IDC_CHECKBOX_RECENT			1006

#define IDD_ICON				103
#define IDC_LIST_ICON				1000

#define IDS_FILTER_SOUND			40000
#define IDS_FILTER_PROGRAM			40001
#define IDS_MSGBOX_DELETE			40002
#define IDS_MSG_ITEM_REQUIRED			40003
#define IDS_MSG_INVALID_CHAR			40004
#define IDS_MSG_NAME_EXISTS			40005
#define IDS_LIST_IP_VERSION			40006
#define IDS_LIST_VERIFY				40007
